@@ -1,16 +1,18 @@
 import os
 os.environ["TOKENIZERS_PARALLELISM"] = "false"
 import math
-import cv2 
+import cv2
 import numpy as np
 import pandas as pd
 from pytubefix import YouTube #19 Fixed pytube issue
-from transformers import AutoProcessor, AutoModel
+from transformers import CLIPProcessor, CLIPModel
+from image import classify_image
 import torch.nn.functional as F
 import time
 
 
-def yt_analyze(url, nframes, labels, side='largest', start = 0, end=-1, uniform = False, ff = 10, frame_dir = 'temp/', video_name = 'temp'):
+def yt_analyze(url, nframes, labels, side='largest', start=0, end=-1, uniform=False,
+               ff=10, frame_dir='temp/', video_name='temp', model_name='oai-base', local_model_path=None):
   nframes = int(nframes)
   start_time = time.time()
   temp_dir =  frame_dir
@@ -99,19 +101,23 @@ def yt_analyze(url, nframes, labels, side='largest', start = 0, end=-1, uniform
         cv2.imwrite(image_path, frame)
         counter += 1
   print(f"Total number of saved frames: {counter}")
-  
+
   for i in range(counter):
     image = os.path.join(frame_dir, f"{video_name}-frame-{i}.jpg")
     if not(image is None):
-      emotions = classify_openai(image,labels, face = side)
+      emotions = classify_image(image, labels, face=side, model_name=model_name, local_model_path=local_model_path)
+      if emotions:
+        # Add the dictionary directly to our list
+        detected_emotions.append(emotions)
+      else:
+        # Create a dictionary with NaN values for each emotion
+        detected_emotions.append({label: np.nan for label in labels})
     else:
-      detected_emotions.append([np.nan]*len(labels))
-    if emotions:
-      detected_emotions.append(list(emotions.values()))
-    else:
-      detected_emotions.append([np.nan]*len(labels))
+      # Create a dictionary with NaN values for each emotion
+      detected_emotions.append({label: np.nan for label in labels})
+  
+  # Convert list of dictionaries to DataFrame - no need to set columns manually
   df = pd.DataFrame(detected_emotions)
-  df.columns = labels
   end_time = time.time()
   print(f"Done! Execution time: {end_time - start_time} seconds")
-  return df 
+  return df
